@@ -8,13 +8,20 @@ from bcoding import bencode, bdecode
 
 class TorrentFile:
     def __init__(self, torrent):
-        logging.getLogger('BitTorrent').critical('Start reading from BitTorrent file')
+        """
+        Initiate the TorrentFile object using the
+        bcoding library that parse the .torrent file,
+        and then calculate the sha1 value of the info dict.
+        this important value will later use us in peer retrieve
+        process and in the handshakes process.
+        """
+        logging.getLogger("BitTorrent").critical("Start reading from BitTorrent file")
         torrent_data = torrent.read()
         self.config = bdecode(torrent_data)
-        self.info = self.config['info']
+        self.info = self.config["info"]
         self.hash = hashlib.sha1(bencode(self.info)).digest()
-        self.piece_size = self.config['info']['piece length']
-        self.file_name = self.config['info']['name']
+        self.piece_size = self.config["info"]["piece length"]
+        self.file_name = self.config["info"]["name"]
         self.length = 0
         self.print_configuration()
         torrent.close()
@@ -27,6 +34,10 @@ class TorrentFile:
             self.length = self.info["length"]
 
     def print_configuration(self):
+        """
+        Help function for printing the configuration of
+        the torrent file in an nice-to-look way using rich.
+        """
         config = deepcopy(self.config)
-        config['info']['pieces'] = ''
+        config["info"]["pieces"] = ""
         rich.print(config)
