@@ -6,6 +6,8 @@ from typing import List
 from PyBitTorrent.Peer import Peer
 from PyBitTorrent.TorrentFile import TorrentFile
 
+COMPACT_VALUE_NUM_BYTES = 6
+
 
 class Tracker(ABC):
     def __init__(self, url):
@@ -17,18 +19,15 @@ class Tracker(ABC):
 
     @staticmethod
     def extract_compact_peers(peers_bytes) -> List[Peer]:
-        # TODO: write new compact mode
         offset = 0
         peers = []
         if not peers_bytes:
             return []
 
-        for _ in range(len(peers_bytes) // 6):
-            ip = struct.unpack_from("!i", peers_bytes, offset)[0]
+        for _ in range(len(peers_bytes) // COMPACT_VALUE_NUM_BYTES):
+            ip, port = struct.unpack_from("!iH", peers_bytes, offset)[0]
             ip = socket.inet_ntoa(struct.pack("!i", ip))
-            offset += 4
-            port = struct.unpack_from("!H", peers_bytes, offset)[0]
-            offset += 2
+            offset += 6
 
             peers.append(Peer(ip, port))
 
